/*
   This file contains most of the boilerplate code that is needed
   by this program. You need to implement all of the event handlers.
   I have defined a few global variables to give you an idea of what
   is needed. Feel free to use or not use these global variables.
*/
#include <iostream>
#include <fstream>

#if defined _WIN32 || defined _WIN64
#  include <windows.h>
#endif

#ifdef __APPLE__
#  include <GLUT/glut.h>
#else
#  include <GL/glut.h>
#endif

using namespace std;

/* Prototypes for the display() and reshape() callback functions */
void display(void);
void reshape(int, int);

/* Prototypes for the mouse event callback functions */
void mouse(int, int, int, int);
void motion(int, int);
void passiveMotion(int, int);
void entry(int);

int windowWidth;    // set by the reshape() callback function
int windowHeight;   // set by the reshape() callback function

int currentIcon = 0;            // set by the mouse() callback function
int mouseState = GLUT_UP;       // set by the mouse() callback function
int mouseClickX, mouseClickY;   // set by the mouse() callback function

int mouseDownX, mouseDownY;     // set by the motion() callback function

int mouseMotionX, mouseMotionY; // set by the passiveMotion() callback function


void drawGRSFile(const char *fileName)
{
   fstream inStream;
   inStream.open(fileName, ios::in);  // open the GRS file
   if(inStream.fail()){cout << "Can't open GRS file: " << fileName; return;};

   // read the comment lines
   char str[80];
   inStream.getline(str, 80, '\n');
   while (str[0] != '*')
      inStream.getline(str, 80, '\n');

   // read the figure extents
   GLfloat left, top, right, bottom;
   inStream >> left >> top >> right >> bottom;

   // set the world window to just hold the image from the GRS file
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(left, right, bottom, top);  // world window

   GLint numPolylines;
   inStream >> numPolylines;              // read the number of polylines
   for(int j = 0; j < numPolylines; j++)  // read each polyline
   {
      GLint numVertices;
      inStream >> numVertices;      // read the number of vertices in this polyline
      GLfloat x ,y;
      glBegin(GL_LINE_STRIP);       // draw this polyline
        for (int i = 0; i < numVertices; i++)
        {
           inStream >> x >> y;  // read the next world coordinate pair
           glVertex2f(x, y);
        }
      glEnd();
   }
   glFlush();        // forces the drawing to take place
   inStream.close(); // close the GRS file
}//drawGRSFile()



int main(int argc, char **argv)
{
   /* Standard GLUT initialization */
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGB);
   glutInitWindowSize(500, 500);
   glutInitWindowPosition(200, 200);
   glutCreateWindow("Hw 2");
   // window event callback functions
   glutDisplayFunc(display);
   glutReshapeFunc(reshape);
   // mouse event callback functions
   glutMouseFunc(mouse);
   glutMotionFunc(motion);
   glutPassiveMotionFunc(passiveMotion);
   glutEntryFunc(entry);

   /* Initialize OpenGL state */
   glClearColor(1.0f, 1.0f, 1.0f, 1.0f);  // background is white

   /* Enter event loop */
   glutMainLoop();

   return 0;  /* we never get here */
}//main()


/* The display() callback function */
void display(void)
{
   glClear(GL_COLOR_BUFFER_BIT);  // clear the current screen buffer



   glutSwapBuffers();  // using double buffering
   printf("We got a \"display()\" event\n");
}//display()


/* The reshape() callback function */
void reshape(int width, int height)
{


   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
   display();
}//reshape()


/* The mouse() callback function */
void mouse(int button, int state, int x, int y)
{


   printf("We got a \"mouse(%d, %d, %d, %d)\" event\n", button, state, x, y);
   display();
}//mouse()


/* The mouse motion() callback function */
void motion(int x, int y)
{


   printf("We got a \"motion(%d, %d)\" event\n", x, y);
   display();
}//motion()


/* The mouse passiveMotion() callback function */
void passiveMotion(int x, int y)
{


   printf("We got a \"passiveMotion(%d, %d)\" event\n", x, y);
   display();
}//passiveMotion()


/* The mouse entry() callback function */
void entry(int state)
{


   printf("We got a \"entry(%d)\" event\n", state);
   display();
}//entry()