/*
   A simple demonstration of loading and drawing a GRS file.
*/
#include <iostream>
#include <fstream>

#if defined _WIN32 || defined _WIN64
#  include <windows.h>
#endif

#ifdef __APPLE__
#  include <GLUT/glut.h>
#else
#  include <GL/glut.h>
#endif

using namespace std;


/*
   The basic structure of a GRS file is:
   1.) A number of comment lines, followed by a line starting with an asterisk, '*'.
   2.) The "extent" of the figure in world coordinates (left, top, right, bottom).
   3.) The number of line-strips (i.e, polylines) in the figure.
   4.) The list of polylines. Each polyline starts with the number of vertices in the
       polyline, followed by the (x, y) world coordinates for each vertex.
*/
void drawGRSFile(const char *fileName)
{
   fstream inStream;
   inStream.open(fileName, ios::in);  // open the GRS file
   if(inStream.fail()){cout << "Can't open GRS file: " << fileName; return;};

   // read the comment lines
   char str[80];
   inStream.getline(str, 80, '\n');
   while (str[0] != '*')
      inStream.getline(str, 80, '\n');

   // read the figure extents
   GLfloat left, top, right, bottom;
   inStream >> left >> top >> right >> bottom;

   // set the world window to just hold the image from the GRS file
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(left, right, bottom, top);  // world window

   GLint numPolylines;
   inStream >> numPolylines;              // read the number of line-strips (also called polylines)
   for(int j = 0; j < numPolylines; j++)  // read each line-strip
   {
      GLint numVertices;
      inStream >> numVertices;      // read the number of vertices in this line-strip
      GLfloat x ,y;
      glBegin(GL_LINE_STRIP);       // draw this line-strip
        for (int i = 0; i < numVertices; i++)
        {
           inStream >> x >> y;  // read the next world coordinate pair
           glVertex2f(x, y);
        }
      glEnd();
   }
   glFlush();        // forces the drawing to take place
   inStream.close(); // close the GRS file
}//drawGRSFile()


void display(void)
{
   glClear(GL_COLOR_BUFFER_BIT);   // clear the buffer

   drawGRSFile("bronto.grs");
}


int main(int argc, char **argv)
{
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
   glutInitWindowSize(640, 480);
   glutInitWindowPosition(100, 100);
   glutCreateWindow("GRS file");
   glutDisplayFunc(display);
   glClearColor(1.0f, 1.0f, 1.0f, 1.0f);
   glColor3f(0.0f, 0.0f, 0.0f);
   glutMainLoop();
   return 0;
}